Datasets
--------

Datasets
========
.. automodule:: gordo.machine.dataset.datasets
    :members:
    :undoc-members:
    :show-inheritance:

Base Dataset
============
.. automodule:: gordo.machine.dataset.base
    :members:
    :undoc-members:
    :show-inheritance:


DataProvider
============

Each dataset requires a data provider, which is
responsible to provide the data to the logic of
the dataset.

.. toctree::
    :maxdepth: 4
    :caption: DataProvider

    ./data_provider.rst

